@@ -6,7 +6,7 @@
 # *
 # * This program is free software; you can redistribute it and/or modify
 # * it under the terms of the GNU General Public License as published by
-# * the Free Software Foundation; either version 2 of the License, or
+# * the Free Software Foundation; either version 3 of the License, or
 # * (at your option) any later version.
 # *
 # * This program is distributed in the hope that it will be useful,
@@ -24,8 +24,5 @@
 # *
 # **************************************************************************
 
-from .test_convert_bsoft import (BaseTest, TestAlignment, TestBasic,
-                                TestConvertBase, TestReconstruct,
-                                TestSetConvert)
 from .test_protocols_bsoft_blocres import (TestBsoftBlocres,
                                           TestBsoftBlocresBase)
